@@ -26,6 +26,7 @@ import sys
 import os
 import json
 import shutil
+import locale
 
 from ._version import __version__
 from . import logging
@@ -98,10 +99,15 @@ def setup(
     templates, and resources directories if they're not explicitly
     provided.
 
+    Set the locale (via LC_ALL) to the configuration's LOCALE value.
+
     This must be called before any of the launch_ functions are run.
     """
     global CONFIG
     CONFIG = config
+    # Set locale
+    locale.setlocale(locale.LC_ALL, config.LOCALE)
+
     # Set specs directory for evaluate.py
     if specs_dir is None:
         specs_dir = os.path.join(config.BASE_DIR, "specs")
