@@ -87,6 +87,56 @@ def get_spec_file_name():
     return result
 
 
+def current_solution_path():
+    """
+    Uses `get_spec_file_name` to figure out where the current
+    specification file is, and assumes that the solution directory is
+    next to that file and named 'soln'. Returns the absolute path to
+    that directory, or raises a FileNotFoundError if it can't find it or
+    if `get_spec_file_name` fails.
+    """
+    fn = get_spec_file_name()
+    if fn == "unknown":
+        raise FileNotFoundError("Couldn't find spec module filename.")
+
+    result = os.path.abspath(os.path.join(os.path.dirname(fn), "soln"))
+    if not os.path.exists(result):
+        raise FileNotFoundError(
+            f"Expected solution directory '{result}' does not exist."
+        )
+    elif not os.path.isdir(result):
+        raise FileNotFoundError(
+            f"Expected solution directory '{result}' is not a directory."
+        )
+
+    return result
+
+
+def current_starter_path():
+    """
+    Uses `get_spec_file_name` to figure out where the current
+    specification file is, and assumes that the starter directory is
+    next to that file and named 'starter'. Returns the absolute path to
+    that directory, or raises a FileNotFoundError if it can't find it or
+    if `get_spec_file_name` fails.
+    """
+    fn = get_spec_file_name()
+    if fn == "unknown":
+        raise FileNotFoundError("Couldn't find spec module filename.")
+
+    result = os.path.abspath(os.path.join(os.path.dirname(fn), "starter"))
+    if not os.path.exists(result):
+        raise FileNotFoundError(
+            f"Expected solution directory '{result}' does not exist."
+        )
+    elif not os.path.isdir(result):
+        raise FileNotFoundError(
+            f"Expected solution directory '{result}' is not a directory."
+        )
+
+    return result
+
+
 def deduce_task_id():
     """
     Uses `get_spec_module_name` to deduce the task ID for the file we're
