@@ -221,10 +221,31 @@ window.addEventListener("load", function () {
     }
 });
 
+// TODO: Fight the CSS battle w/ overflow to make sticky bin tabs work in
+// Safari... T_T (use padding?!?)
+
+
 /*----------------------*
  * Feedback interaction *
  *----------------------*/
 
+/* Hides (or shows) all accomplished goals (not categories) */
+function hide_accomplished_goals(hide) {
+    if (hide == undefined) { hide = true; }
+    for (
+        let row
+        of document.querySelectorAll(
+            "div.rubric_row.status_accomplished:not(.goal_category)"
+        )
+    ) {
+        if (hide) {
+            row.style.display = "none";
+        } else {
+            row.style.display = "block";
+        }
+    }
+}
+
 window.addEventListener("load", function () {
     let hide_accomplished = document.getElementById(
         "hide_accomplished_goals"
@@ -234,40 +255,62 @@ window.addEventListener("load", function () {
             "change",
             function () {
                 if (hide_accomplished.checked) {
-                    for (
-                        let row
-                     of document.querySelectorAll(
-                     "div.rubric_row.status_accomplished:not(.goal_category)"
-                        )
-                    ) {
-                        row.style.display = "none";
-                    }
+                    hide_accomplished_goals();
                 } else {
-                    for (
-                        let row
-                     of document.querySelectorAll(
-                     "div.rubric_row.status_accomplished:not(.goal_category)"
-                        )
-                    ) {
-                        row.style.display = "block";
-                    }
+                    hide_accomplished_goals(false);
                 }
             }
         );
         if (hide_accomplished.checked) {
-            for (
-                let row
-             of document.querySelectorAll(
-                    "div.rubric_row.status_accomplished:not(.goal_category)"
-                )
-            ) {
-                row.style.display = "none";
-            }
+            hide_accomplished_goals();
         }
     }
 });
 
 
+/* Styles (or unstyles) all goal links */
+function style_goal_links(style) {
+    if (style == undefined) { style = true; }
+    for (let row of document.querySelectorAll("a.rubric_link")) {
+        if (style) {
+            row.classList.remove("unstyled");
+        } else {
+            row.classList.add("unstyled");
+        }
+    }
+}
+
+
+/* Toggle for link decoration */
+window.addEventListener("load", function () {
+    let decoration_toggle = document.getElementById(
+        "decorate_goal_links"
+    );
+    if (decoration_toggle != null) {
+        decoration_toggle.addEventListener(
+            "change",
+            function () {
+                if (decoration_toggle.checked) {
+                    style_goal_links();
+                } else {
+                    style_goal_links(false);
+                }
+            }
+        );
+        /* TODO: Get event right instead of 'load' so content is actually
+         * ready */
+        window.setTimeout(
+            function () {
+                if (decoration_toggle.checked) {
+                    style_goal_links();
+                }
+            },
+            1
+        );
+    }
+});
+
+
 /*-------------*
  * Sticky bins *
  *-------------*/
@@ -643,6 +686,7 @@ window.addEventListener("load", function () {
             if (to_id.startsWith("goal:")) {
                 // Add a class
                 link.classList.add("rubric_link");
+                link.classList.add("unstyled"); // start unstyled
 
                 // Figure out category based on parent row's class
                 let row = destination.parentNode;
