@@ -583,7 +583,7 @@ class Snippet(specifications.TestGroup):
             base_context["task_info"]["specification"].soln_path
         )
         for context in context_dicts:
-            if soln_path in context["output"]:
+            if "output" in context and soln_path in context["output"]:
                 context["output"] = context["output"].replace(
                     soln_path,
                     '&lt;soln&gt;'
@@ -1162,8 +1162,20 @@ class Files(Snippet):
     running any code, in the same Jupyter-like format that file contents
     are shown when `Snippet.show_file_contents` is used. Most
     specialization methods don't work properly on this kind of snippet.
+
+    By default, file paths are interpreted as relative to the solutions
+    directory, but specifying a different base directory via the
+    constructor can change that.
     """
-    def __init__(self, sid, title, caption, filepaths, postscript=''):
+    def __init__(
+        self,
+        sid,
+        title,
+        caption,
+        filepaths,
+        base='__soln__',
+        postscript=''
+    ):
         """
         A snippet ID, title, and caption are required, along with a list
         of file paths. Each entry in the list should be a string path to
@@ -1172,9 +1184,26 @@ class Files(Snippet):
         present in both starter and solution directories will be
         available.
 
+        If `base` is specified, it should be either '__soln__' (the
+        default), '__starter__', or a path string. If it's __soln__ paths
+        will be interpreted relative to the solution directory; if it's
+        __starter__ they'll be interpreted relative to the starter
+        directory, and for any other path, paths are interpreted relative
+        to that directory. In any case, absolute paths will not be
+        modified.
+
         A postscript is optional (see `Snippet`).
         """
-        self.filepaths = filepaths
+        if base == "__soln__":
+            base = file_utils.current_solution_path()
+        elif base == "__starter__":
+            base = file_utils.current_starter_path()
+        # else leave base as-is
+
+        self.filepaths = {
+            path: os.path.join(base, path)
+            for path in filepaths
+        }
 
         super().__init__(sid, title, caption, [], postscript)
 
@@ -1184,7 +1213,8 @@ class Files(Snippet):
         which depends on dummy contexts.
         """
         ctx_list = []
-        for filepath in self.filepaths:
+        for showpath in self.filepaths:
+            filepath = self.filepaths[showpath]
             with open(filepath, 'r', encoding="utf-8") as fileInput:
                 contents = fileInput.read()
 
@@ -1194,10 +1224,14 @@ class Files(Snippet):
                 loop, which is why this extra layer of indirection is
                 added.
                 """
-                nonlocal filepath, contents
+                nonlocal showpath, filepath, contents
+                sp = showpath
+                fp = filepath
+                ct = contents
                 return lambda _: {
-                    "path": filepath,
-                    "contents": contents
+                    "path": sp,
+                    "real_path": fp,
+                    "contents": ct
                 }
 
             ctx_list.append(contexts.Context(builder=make_builder()))
