@@ -35,7 +35,7 @@ RUBRIC_EXPECTS = {
             " invariants for the <code>position</code> and"
             " <code>heading</code> values"
         ),
-        "<code>ellipseArea</code> returns the correct result",
+        "<code>ellipseArea</code> must return the correct result",
     ],
     "freedomTest": [ "<title>freedomTest Rubric</title>" ],
     "snippetsTest": [
@@ -44,11 +44,11 @@ RUBRIC_EXPECTS = {
         "Product Requirements",
         "Core goals",
         "processData",
-        "returns the correct result",
+        "must return the correct result",
         "Behavior Requirements",
         "Extra goals",
         "process.py",
-        "exhibits the correct behavior"
+        "must exhibit the correct behavior"
     ],
     "filesTest": [ "<title>filesTest Rubric</title>" ],
     "varsTest": [ "<title>varsTest Rubric</title>" ],
