@@ -1898,21 +1898,22 @@ The flask app's configuration object.
 """
 
 
-def init(config, port=51723, key=None):
+def init(config, key=None):
     """
     `init` should be called once per process, ideally early in the life of
     the process, like right after importing the module. Calling
     some functions before `init` will fail. A file named 'redis-pw.conf'
     should exist unless a key is given (should be a byte-string). If
-    'redis-pw.conf' doesn't exist, it will be created. Don't rely too
-    heavily on the default port, since any two apps using sync with the
-    default port on the same machine will collide.
+    'redis-pw.conf' doesn't exist, it will be created.
     """
     global _REDIS, _CONFIG
 
     # Store config object
     _CONFIG = config
 
+    # Grab port from config
+    port = config.get("STORAGE_PORT", 51723)
+
     # Redis configuration filenames
     rconf_file = "potluck-redis.conf"
     ruser_file = "potluck-redis-user.acl"
